@@ -1,9 +1,12 @@
 simY_frn <-
-function(EZ,rho,odmax)
+function(EZ,rho,odmax,YO=NULL)
 { 
   if(length(odmax)==1) { odmax<-rep(odmax,nrow(EZ)) }
   ZS<-simZ(EZ,rho)  
+  
   diag(ZS)<- -Inf
+  if(!is.null(YO)) { ZS[is.na(YO)]<- -Inf } 
+
   YS<-ZS*0 
   for(i in 1:nrow(EZ))
   {
@@ -11,6 +14,8 @@ function(EZ,rho,odmax)
     YS[i,]<-rs*(rs>0)*(ZS[i,]>0) 
     YS[i,YS[i,]>0 ] <- match( YS[i,YS[i,]>0 ] ,sort(unique(YS[i,YS[i,]>0 ]))) 
   }
-diag(YS)<-NA 
+  diag(YS)<-NA 
+  if(!is.null(YO)) { YS[is.na(YO)]<- NA } 
+
 YS
 }
